@@ -30,7 +30,7 @@ EXAMPLES::
 # -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2021, UChicago Argonne, LLC
+# :copyright: (c) 2017-2022, UChicago Argonne, LLC
 #
 # Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
 #
@@ -39,41 +39,30 @@ EXAMPLES::
 
 
 from collections import OrderedDict
-from ophyd.device import (
-    Device,
-    Component as Cpt,
-    DynamicDeviceComponent as DDC,
-    FormattedComponent as FC,
-)
+from ophyd import Device
+from ophyd import Component as Cpt
+from ophyd import DynamicDeviceComponent as DDC
+from ophyd import FormattedComponent as FC
 from ophyd import EpicsSignal
 from ophyd.signal import EpicsSignalBase
 
 from ._common import EpicsRecordDeviceCommonAll
 from .. import utils as APS_utils
 
-__all__ = """
-    SwaitRecord
-    SwaitRecordChannel
-    UserCalcsDevice
-    setup_random_number_swait
-    setup_gaussian_swait
-    setup_lorentzian_swait
-    setup_incrementer_swait
-""".split()
 
 CHANNEL_LETTERS_LIST = "A B C D E F G H I J K L".split()
 
 
 class SwaitRecordChannel(Device):
     """
-    channel of a synApps swait record: A-L
+    EPICS synApps synApps swait record: single channel [A-L]
 
     .. index:: Ophyd Device; synApps SwaitRecordChannel
     """
 
-    input_value = FC(EpicsSignal, "{self.prefix}.{self._ch_letter}")
-    input_pv = FC(EpicsSignal, "{self.prefix}.IN{self._ch_letter}N")
-    input_trigger = FC(EpicsSignal, "{self.prefix}.IN{self._ch_letter}P")
+    input_value = FC(EpicsSignal, "{self.prefix}.{self._ch_letter}", kind="normal")
+    input_pv = FC(EpicsSignal, "{self.prefix}.IN{self._ch_letter}N", kind="config")
+    input_trigger = FC(EpicsSignal, "{self.prefix}.IN{self._ch_letter}P", kind="config")
     read_attrs = [
         "input_value",
     ]
@@ -99,7 +88,7 @@ def _swait_channels(channel_list):
 
 class SwaitRecord(EpicsRecordDeviceCommonAll):
     """
-    synApps swait record: used as ``$(P):userCalc$(N)``
+    EPICS synApps swait record: used as ``$(P):userCalc$(N)``
 
     .. index:: Ophyd Device; synApps SwaitRecord
 
@@ -108,22 +97,23 @@ class SwaitRecord(EpicsRecordDeviceCommonAll):
         ~reset
 
     """
+    enable = Cpt(EpicsSignal, "Enable", kind="config")
 
-    precision = Cpt(EpicsSignal, ".PREC")
-    high_operating_range = Cpt(EpicsSignal, ".HOPR")
-    low_operating_range = Cpt(EpicsSignal, ".LOPR")
+    precision = Cpt(EpicsSignal, ".PREC", kind="config")
+    high_operating_range = Cpt(EpicsSignal, ".HOPR", kind="config")
+    low_operating_range = Cpt(EpicsSignal, ".LOPR", kind="config")
 
-    calculated_value = Cpt(EpicsSignal, ".VAL")
-    calculation = Cpt(EpicsSignal, ".CALC")
+    calculated_value = Cpt(EpicsSignal, ".VAL", kind="hinted")
+    calculation = Cpt(EpicsSignal, ".CALC", kind="config")
 
-    output_link_pv = Cpt(EpicsSignal, ".OUTN")
-    output_location_name = Cpt(EpicsSignal, ".DOLN")
-    output_location_data = Cpt(EpicsSignal, ".DOLD")
-    output_data_option = Cpt(EpicsSignal, ".DOPT")
+    output_link_pv = Cpt(EpicsSignal, ".OUTN", kind="config")
+    output_location_name = Cpt(EpicsSignal, ".DOLN", kind="config")
+    output_location_data = Cpt(EpicsSignal, ".DOLD", kind="config")
+    output_data_option = Cpt(EpicsSignal, ".DOPT", kind="config")
 
-    output_execute_option = Cpt(EpicsSignal, ".OOPT")
-    output_execution_delay = Cpt(EpicsSignal, ".ODLY")
-    event_to_issue = Cpt(EpicsSignal, ".OEVT")
+    output_execute_option = Cpt(EpicsSignal, ".OOPT", kind="config")
+    output_execution_delay = Cpt(EpicsSignal, ".ODLY", kind="config")
+    event_to_issue = Cpt(EpicsSignal, ".OEVT", kind="config")
 
     read_attrs = APS_utils.itemizer("channels.%s", CHANNEL_LETTERS_LIST)
     hints = {"fields": read_attrs}
@@ -161,7 +151,7 @@ class SwaitRecord(EpicsRecordDeviceCommonAll):
 
 class UserCalcsDevice(Device):
     """
-    synApps XXX IOC setup of userCalcs: ``$(P):userCalc$(N)``
+    EPICS synApps XXX IOC setup of userCalcs: ``$(P):userCalc$(N)``
 
     .. index:: Ophyd Device; synApps UserCalcsDevice
 
@@ -171,7 +161,7 @@ class UserCalcsDevice(Device):
 
     """
 
-    enable = Cpt(EpicsSignal, "userCalcEnable")
+    enable = Cpt(EpicsSignal, "userCalcEnable", kind="config")
     calc1 = Cpt(SwaitRecord, "userCalc1")
     calc2 = Cpt(SwaitRecord, "userCalc2")
     calc3 = Cpt(SwaitRecord, "userCalc3")
@@ -251,20 +241,15 @@ def _setup_peak_swait_(
 
     # consider a noisy background, as well (needs a couple calcs)
     if not isinstance(swait, SwaitRecord):
-        raise TypeError(
-            "expected SwaitRecord instance," f" received {type(swait)}"
-        )
+        raise TypeError("expected SwaitRecord instance," f" received {type(swait)}")
     if not isinstance(ref_signal, EpicsSignalBase):
         raise TypeError(
-            "expected EpicsSignalBase instance,"
-            f" received {type(ref_signal)}"
+            "expected EpicsSignalBase instance," f" received {type(ref_signal)}"
         )
     if width <= 0:
         raise ValueError(f"width must be positive, received {width}")
     if not (0.0 <= noise <= 1.0):
-        raise ValueError(
-            f"noise must be between 0 and 1, received {noise}"
-        )
+        raise ValueError(f"noise must be between 0 and 1, received {noise}")
 
     swait.reset()
     swait.scanning_rate.put("Passive")
@@ -283,9 +268,7 @@ def _setup_peak_swait_(
     swait.hints = {"fields": swait.read_attrs}
 
 
-def setup_gaussian_swait(
-    swait, ref_signal, center=0, width=1, scale=1, noise=0.05
-):
+def setup_gaussian_swait(swait, ref_signal, center=0, width=1, scale=1, noise=0.05):
     """
     setup swait for noisy Gaussian
 
@@ -333,9 +316,7 @@ def setup_gaussian_swait(
     )
 
 
-def setup_lorentzian_swait(
-    swait, ref_signal, center=0, width=1, scale=1, noise=0.05
-):
+def setup_lorentzian_swait(swait, ref_signal, center=0, width=1, scale=1, noise=0.05):
     """
     setup swait record for noisy Lorentzian
 
